@@ -618,6 +618,16 @@ public class I2PTunnelServer extends I2PTunnelTask implements Runnable {
                 if (rv <= 0)
                     rv = DEFAULT_HANDLER_COUNT;
             } catch (NumberFormatException nfe) {}
+        } else {
+            // if PROP_MAX_STREAMS is higher, use it
+            cnt = getTunnel().getClientOptions().getProperty(TunnelController.PROP_MAX_STREAMS);
+            if (cnt != null) {
+                try {
+                    int rv2 = Integer.parseInt(cnt) + 10;  // add some extra
+                    if (rv2 > rv)
+                        rv = rv2;
+                } catch (NumberFormatException nfe) {}
+            }
         }
         return rv;
     }
@@ -757,6 +767,19 @@ public class I2PTunnelServer extends I2PTunnelTask implements Runnable {
 
     public boolean shouldUsePool() { return _usePool; }
     
+    /**
+     * Run in the server pool, unless not configured for that,
+     * then in the client pool.
+     *
+     * @since 0.9.66
+     */
+    protected void executeInPool(Runnable r) {
+        if (_usePool && _executor != null)
+            _executor.execute(r);
+        else
+            _clientExecutor.execute(r);
+    }
+
     /**
      * Run the blockingHandler.
      */
